@@ -2,12 +2,10 @@
 Account
 =======
 """
-
-from __future__ import annotations
-
 from typing import Optional, List, Union
 
 import requests
+from requests import Response
 
 import deepcrawl
 from deepcrawl.projects.projects import DeepCrawlProject
@@ -16,6 +14,7 @@ from deepcrawl.utils import ImmutableAttributesMixin, safe_string_to_datetime
 account_extra_fields = (
     "id",
     "projects",
+    "account_users",
 )
 
 account_mutable_fields = account_extra_fields + (
@@ -95,6 +94,7 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
     def __init__(self, account_data: dict):
         self.id = account_data.get("id")
         self.projects = []
+        self.account_users = []
 
         self.active = account_data.get('active')
         self.address_city = account_data.get('address_city')
@@ -200,11 +200,37 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         self.projects: List[DeepCrawlProject] = connection.get_projects(self.id, filters=filters, **kwargs)
         return self.projects
 
+    def load_account_users(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List['deepcrawl.accounts_users.DeepCrawlUser']:
+        """Loads account users into current instance
+
+        >>> self.load_account_users()
+        [FirstName1 LastName1 email1@localhost.com,
+        FirstName2 LastName2 email2@localhost.com]
+        >>> self.load_account_users()
+        [FirstName1 LastName1 email1@localhost.com,
+        FirstName2 LastName2 email2@localhost.com]
+
+        :param filters: filters dict
+        :type filters: dict
+        :param kwargs: pagination arguments
+        :type kwargs: dict
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: list of account users
+        :rtype: list
+        :return:
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        self.account_users: List['deepcrawl.accounts_users.DeepCrawlUser'] = connection.get_account_users(self.id, filters=filters, **kwargs)
+        return self.account_users
+
     """
     ACCOUNT
     """
 
-    def save(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlAccount:
+    def save(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> 'deepcrawl.accounts.DeepCrawlAccount':
         """Save account instance
 
         * if the instance id is None then the account will be created
@@ -224,7 +250,9 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         else:
             return connection.update_account(self.id, {key: getattr(self, key) for key in self.post_fields})
 
-    def refresh(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlAccount:
+    def refresh(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> 'deepcrawl.accounts.DeepCrawlAccount':
         """Makes a call to DeepCrawl in order to refresh the current instance.
 
         >>> self.refresh()
@@ -241,7 +269,9 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
             setattr(self, key, getattr(account, key))
         return self
 
-    def update(self, account_settings, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlAccount:
+    def update(
+            self, account_settings, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> 'deepcrawl.accounts.DeepCrawlAccount':
         """Updates an instance with account_settings
 
         >>> self.update(account_settings)
@@ -261,6 +291,74 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
             setattr(self, key, getattr(account, key))
         return self
 
+    """
+    USERS
+    """
+
+    def get_account_users(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List['deepcrawl.accounts_users.DeepCrawlUser']:
+        """Get account users
+
+        * use_cache=True > get_account_users will return cached account_users or will do a call to DeepCrawl if account_users attribute is empty.
+        * use_cache=False > get_account_users will call DeepCrawl api and will override account_users attribute.
+
+        >>> self.get_account_users()
+        [FirstName1 LastName1 email1@localhost.com,
+        FirstName2 LastName2 email2@localhost.com]
+
+        :param use_cache:
+        :type use_cache: bool
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :param filters: filters dict
+        :type filters: dict
+        :param kwargs: extra arguments like pagination arguments
+        :type kwargs: dict
+        :return: list of account users
+        :rtype: list
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        if use_cache and self.account_users:
+            return self.account_users
+        return self.load_account_users(connection=connection, filters=filters, **kwargs)
+
+    def get_account_user(
+            self, uid: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> 'deepcrawl.accounts_users.DeepCrawlUser':
+        """Get a user using the user id
+
+        >>> self.get_account_user(1)
+        FirstName1 LastName1 email1@localhost.com
+
+        :param uid: user id
+        :type uid: int or str
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: The requested user or 404
+        :rtype: DeepCrawlUser
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        return connection.get_account_user(self.id, uid)
+
+    def remove_account_user(self, uid: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None) -> Response:
+        """Remove user from account
+
+        >>> response = connection.remove_account_user(1, 0)
+        >>> response.status_code
+        204
+
+        :param uid: user id
+        :type uid: int or str
+        :param connection: connection
+        :type connection: deepcrawl.DeepCrawlConnection
+        :return: Http response
+        :rtype: Response
+        """
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        return connection.remove_account_user(self.id, uid)
+
     """
     PROJECTS
     """
@@ -344,7 +442,7 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
 
     def get_projects(
             self, use_cache: bool = True,
-            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
     ) -> List[DeepCrawlProject]:
         """Get projects
 
@@ -359,10 +457,12 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
         :param filters: filters dict
+        :param kwargs: extra arguments like pagination arguments
+        :type kwargs: dict
         :return: list of projects
         :rtype: list
         """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         if use_cache and self.projects:
             return self.projects
-        return self.load_projects(connection=connection, filters=filters)
+        return self.load_projects(connection=connection, filters=filters, **kwargs)
