@@ -6,10 +6,21 @@ ENDPOINTS = {
     # auth
     "session": "sessions",
 
+    # Users
+    "users": "users",
+    "user_resend": "users/{uid}/resend",
+    "user_set_password": "users/{uid}/set_password",
+
     # Accounts
     "account": "accounts/{account_id}",
     "accounts": "accounts",
 
+    # Account Users
+    "user_account": "users/{uid}/accounts/{account_id}",
+    "user_accounts": "users/{uid}/accounts",
+    "account_user": "accounts/{account_id}/users/{uid}",
+    "account_users": "accounts/{account_id}/users",
+
     # Projects
     "project": "accounts/{account_id}/projects/{project_id}",
     "projects": "accounts/{account_id}/projects",
@@ -47,7 +58,17 @@ ENDPOINTS = {
     "report_download": "accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/reports/{report_id}/"
                        "downloads/{report_download_id}",
     "report_downloads": "accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/reports/{report_id}/"
-                        "downloads"
+                        "downloads",
+
+    # Statistics
+    "report_statistics": "accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/reports/{report_id}/"
+                         "statistics",
+    "report_statistic": "/accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/reports/{report_id}/"
+                        "statistics/{statistic_type}",
+    "crawl_statistics": "accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/statistics",
+    "crawl_statistic": "accounts/{account_id}/projects/{project_id}/crawls/{crawl_id}/statistics/{statistic_type}",
+    "issue_statistics": "accounts/{account_id}/projects/{project_id}/issues/{issue_id}/statistics",
+    "issue_statistic": "accounts/{account_id}/projects/{project_id}/issues/{issue_id}/statistics/{statistic_type}"
 }
 
 
