@@ -2,8 +2,6 @@
 Project
 =======
 """
-from __future__ import annotations
-
 from typing import Union, Optional, List
 
 from requests import Response
@@ -228,7 +226,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     PROJECT
     """
 
-    def save(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlProject:
+    def save(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> 'deepcrawl.projects.DeepCrawlProject':
         """Save project instance
 
         * if the instance id is None then the project will be created
@@ -248,7 +246,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         else:
             return connection.update_project_settings(self.account_id, self.id, self.project_settings.to_dict)
 
-    def refresh(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlProject:
+    def refresh(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> 'deepcrawl.projects.DeepCrawlProject':
         """Makes a call to DeepCrawl in order to refresh the current instance.
 
         >>> self.refresh()
@@ -267,7 +265,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
 
     def update_settings(
             self, project_settings: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
-    ) -> DeepCrawlProject:
+    ) -> 'deepcrawl.projects.DeepCrawlProject':
         """Updates current project instance with another project_settings.
         Settings argument can be dict or a ProjectSettings instance.
 
@@ -303,8 +301,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         return response
 
     def add_extractions(
-            self, extractions: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
-    ) -> DeepCrawlProject:
+            self, extractions: list, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> 'deepcrawl.projects.DeepCrawlProject':
         """Add extractions to current project
 
         .. code-block::
